==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/space/messages/ru/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Это сообщество по прежнему пусто!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Это сообщество ещё пусто!</b><br>Начните активность в нём, разместив что-нибудь здесь...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Вы не участник данного сообщества, а общедоступного контента пока нет!</b>',
    '<strong>Confirm</strong> image deletion' => '<strong>Подтвердите</strong> удаление изображения',
    '<strong>Invite</strong> members' => '<strong>Пригласить</strong> пользователей',
    '<strong>New</strong> member request' => '<strong>Новые</strong> запросы на вступление',
    '<strong>New</strong> spaces' => '<strong>Новые</strong> сообщества',
    '<strong>Request</strong> space membership' => '<strong>Отправить</strong> запрос на вступление',
    '<strong>Space</strong> followers' => '<strong>Подписчики</strong> сообщества',
    '<strong>Space</strong> members' => '<strong>Участники</strong> сообщества',
    '<strong>Space</strong> menu' => '<strong>Меню</strong> сообщества',
    'About' => 'Обо мне',
    'Accept' => 'Активировать',
    'Accept Invite' => 'Принять приглашение',
    'Add users without invitation' => 'Добавить пользователей без приглашения',
    'Admin' => 'Администратор',
    'Administrator:' => 'Администратор:',
    'Administrators' => 'Администраторы',
    'Application message' => 'Сообщение',
    'Archived' => 'В архиве',
    'As owner you cannot revoke your membership!' => 'Как владелец, Вы не можете покинуть это сообщество!',
    'Cancel' => 'Отменить',
    'Close' => 'Закрыть',
    'Color' => 'Цвет',
    'Could not request membership!' => 'Не удалось выполнить запрос на вступление в сообщество!',
    'Created At' => 'Создано в',
    'Created By' => 'Создано',
    'Decline' => 'Отказать',
    'Decline Invite' => 'Отменить приглашение',
    'Default' => 'По умолчанию',
    'Default content visibility' => 'Видимость контента по умолчанию',
    'Delete' => 'Удалить',
    'Description' => 'Описание',
    'Do you really want to delete your profile image?' => 'Вы действительно хотите удалить изображение профиля?',
    'Do you really want to delete your title image?' => 'Вы действительно хотите удалить изображение обложки?',
    'Done' => 'Выполнено',
    'Email addresses' => 'Адреса электронной почты',
    'Everyone can enter' => 'Каждый может вступить',
    'Follow' => 'Подписаться',
    'Followers' => 'Подписчиков',
    'Following' => 'Подписан(а)',
    'Homepage' => 'Главная страница',
    'Homepage (Guests)' => 'Главная страница (для гостей)',
    'Invite' => 'Пригласить',
    'Invite and request' => 'Приглашение и запрос',
    'Invite by email' => 'Пригласить с помощью электронной почты',
    'Invites' => 'Приглашения',
    'Join Policy' => 'Регистрационная политика',
    'Last Visit' => 'Последний визит',
    'Login' => 'Войти',
    'Members' => 'Участники',
    'Moderator:' => 'Модератор:',
    'Moderators' => 'Модераторы',
    'My Space List' => 'Мои сообщества',
    'My space summary' => 'Сводка сообществ',
    'Name' => 'Название',
    'New user by e-mail (comma separated)' => 'Адреса электронной почты новых пользователей (через запятую)',
    'New user?' => 'Новый пользователь?',
    'No spaces found.' => 'Сообщества не найдены.',
    'Only by invite' => 'Только по приглашению',
    'Originator User ID' => 'Первоисточник User ID',
    'Owner' => 'Владелец',
    'Owner:' => 'Владелец:',
    'Pending' => 'В ожидании',
    'Pick users' => 'Зарегистрированные пользователи',
    'Please shortly introduce yourself, to become an approved member of this space.' => 'Пожалуйста, представьтесь, чтобы стать участником сообщества.',
    'Posts' => 'Записей',
    'Private' => 'Закрытые сообщества',
    'Private (Invisible)' => 'Закрытое сообщество (скрытое ото всех, кроме его участников)',
    'Public' => 'Открытые сообщества',
    'Public (Members & Guests)' => 'Публичное (Участники и Гости)',
    'Public (Members only)' => 'Публичное (только Участники)',
    'Public (Registered users only)' => 'Видимо для Пользователей (только для зарегистрированных)',
    'Request Message' => 'Запрашиваемое сообщение',
    'Role' => 'Роль',
    'See all' => 'Посмотреть все',
    'Select all registered users' => 'Выбрать всех зарегистрированных пользователей',
    'Send' => 'Отправить',
    'Settings' => 'Настройки',
    'Show all' => 'Показать всех',
    'Sorry, you are not allowed to leave this space!' => 'Извините, Вам не разрешено покинуть это сообщество',
    'Sorting' => 'Сортировка',
    'Space' => 'Сообщество',
    'Space directory' => 'Директория сообщества',
    'Space is invisible!' => 'Сообщество скрыто!',
    'Spaces' => 'Сообщества',
    'Status' => 'Статус',
    'Stream' => 'Активность',
    'Tags' => 'Теги',
    'There is no pending invite!' => 'Нет ожидающих приглашений!',
    'This action is only available for workspace members!' => 'Это действие доступно только для участников этого сообщества!',
    'This user is already a member of this space.' => 'Этот пользователь уже является участником этого сообщества.',
    'This user is not a member of this space.' => 'Этот пользователь не является участником этого сообщества.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Чтобы пригласить пользователей в это сообщество, введите их имена ниже, чтобы найти и выбрать их.',
    'Updated At' => 'Обновлено в',
    'Updated By' => 'Обновлено',
    'Updated by' => 'Обновлено',
    'User \'{username}\' is already a member of this space!' => 'Пользователь \'{username}\' уже является участником этого сообщества!',
    'User invitations have been added to the queue' => 'Приглашения на вступления для пользователей добавлены',
    'User memberships have been added to the queue' => 'Пользователи приглашены для вступления',
    'User not found!' => 'Пользователь не найден!',
    'Users' => 'Пользователи',
    'Users has been invited.' => 'Пользователи были приглашены.',
    'Visibility' => 'Видимость сообщества',
    'Visible for all (members and guests)' => 'Видимо для всех (для Участников и Гостей)',
    'You are not allowed to join this space!' => 'Вы не можете присоединиться к этому сообществу!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Вы также можете пригласить людей, которые не зарегистрированы в настоящее время. Просто добавьте их адреса электронной почты через запятую.',
    'You cannot create private visible spaces!' => 'Вы не можете создавать закрытые сообщества!',
    'You cannot create public visible spaces!' => 'Вы не можете создавать открытые (публичные) сообщества!',
    'You need to login to view contents of this space!' => 'Вы должны войти/зарегистрироваться, чтобы просматривать содержимое этого сообщества!',
    'Your request was successfully submitted to the space administrators.' => 'Ваша заявка на вступление была успешно отправлена администратору сообщества.',
    '{count} members' => '{count} участников',
    '{email} is not valid!' => '{email} некорректный!',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Find Spaces by their description or by their tags' => '',
    'Guests' => '',
    'Hide Members sidebar in the stream page.' => '',
    'Join' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Moderator' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Search...' => '',
    'Settings could not be saved!' => '',
    'Shown on About Page.' => '',
    'Space Visibility' => '',
    'Try other keywords or remove filters.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/space/messages/ru/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Это сообщество по прежнему пусто!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Это сообщество ещё пусто!</b><br>Начните активность в нём, разместив что-нибудь здесь...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Вы не участник данного сообщества, а общедоступного контента пока нет!</b>',
    '<strong>Confirm</strong> image deletion' => '<strong>Подтвердите</strong> удаление изображения',
    '<strong>Invite</strong> members' => '<strong>Пригласить</strong> пользователей',
    '<strong>New</strong> member request' => '<strong>Новые</strong> запросы на вступление',
    '<strong>New</strong> spaces' => '<strong>Новые</strong> сообщества',
    '<strong>Request</strong> Membership' => '<strong>Отправить</strong> запрос на вступление',
    '<strong>Space</strong> followers' => '<strong>Подписчики</strong> сообщества',
    '<strong>Space</strong> members' => '<strong>Участники</strong> сообщества',
    '<strong>Space</strong> menu' => '<strong>Меню</strong> сообщества',
    'About' => 'Обо мне',
    'Accept' => 'Активировать',
    'Accept Invite' => 'Принять приглашение',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Пожалуйста, представьтесь, чтобы стать участником сообщества.',
    'Add users without invitation' => 'Добавить пользователей без приглашения',
    'Admin' => 'Администратор',
    'Administrator:' => 'Администратор:',
    'Administrators' => 'Администраторы',
    'Archived' => 'В архиве',
    'As owner you cannot revoke your membership!' => 'Как владелец, Вы не можете покинуть это сообщество!',
    'Cancel' => 'Отменить',
    'Close' => 'Закрыть',
    'Color' => 'Цвет',
    'Could not request membership!' => 'Не удалось выполнить запрос на вступление в сообщество!',
    'Created At' => 'Создано в',
    'Created By' => 'Создано',
    'Decline' => 'Отказать',
    'Decline Invite' => 'Отменить приглашение',
    'Default' => 'По умолчанию',
    'Default content visibility' => 'Видимость контента по умолчанию',
    'Delete' => 'Удалить',
    'Description' => 'Описание',
    'Do you really want to delete your profile image?' => 'Вы действительно хотите удалить изображение профиля?',
    'Do you really want to delete your title image?' => 'Вы действительно хотите удалить изображение обложки?',
    'Done' => 'Выполнено',
    'Email addresses' => 'Адреса электронной почты',
    'Everyone can enter' => 'Каждый может вступить',
    'Follow' => 'Подписаться',
    'Followers' => 'Подписчиков',
    'Following' => 'Подписан(а)',
    'Homepage' => 'Главная страница',
    'Invite' => 'Пригласить',
    'Invite and request' => 'Приглашение и запрос',
    'Invite by email' => 'Пригласить с помощью электронной почты',
    'Invites' => 'Приглашения',
    'Join Policy' => 'Регистрационная политика',
    'Last Visit' => 'Последний визит',
    'Login' => 'Войти',
    'Members' => 'Участники',
    'Moderator:' => 'Модератор:',
    'Moderators' => 'Модераторы',
    'My Space List' => 'Мои сообщества',
    'My space summary' => 'Сводка сообществ',
    'Name' => 'Название',
    'New user by e-mail (comma separated)' => 'Адреса электронной почты новых пользователей (через запятую)',
    'New user?' => 'Новый пользователь?',
    'No spaces found.' => 'Сообщества не найдены.',
    'Only by invite' => 'Только по приглашению',
    'Originator User ID' => 'Первоисточник User ID',
    'Owner' => 'Владелец',
    'Owner:' => 'Владелец:',
    'Pending' => 'В ожидании',
    'Pick users' => 'Зарегистрированные пользователи',
    'Posts' => 'Записей',
    'Private' => 'Закрытые сообщества',
    'Private (Invisible)' => 'Закрытое сообщество (скрытое ото всех, кроме его участников)',
    'Public' => 'Открытые сообщества',
    'Public (Members & Guests)' => 'Публичное (Участники и Гости)',
    'Public (Members only)' => 'Публичное (только Участники)',
    'Public (Registered users only)' => 'Видимо для Пользователей (только для зарегистрированных)',
    'Request Message' => 'Запрашиваемое сообщение',
    'Role' => 'Роль',
    'Search...' => 'Поиск...',
    'See all' => 'Посмотреть все',
    'Select all registered users' => 'Выбрать всех зарегистрированных пользователей',
    'Send' => 'Отправить',
    'Settings' => 'Настройки',
    'Show all' => 'Показать всех',
    'Sorry, you are not allowed to leave this space!' => 'Извините, Вам не разрешено покинуть это сообщество',
    'Sorting' => 'Сортировка',
    'Space' => 'Сообщество',
    'Space directory' => 'Директория сообщества',
    'Space is invisible!' => 'Сообщество скрыто!',
    'Spaces' => 'Сообщества',
    'Status' => 'Статус',
    'Stream' => 'Активность',
    'Tags' => 'Теги',
    'There is no pending invite!' => 'Нет ожидающих приглашений!',
    'This action is only available for workspace members!' => 'Это действие доступно только для участников этого сообщества!',
    'This user is already a member of this space.' => 'Этот пользователь уже является участником этого сообщества.',
    'This user is not a member of this space.' => 'Этот пользователь не является участником этого сообщества.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Чтобы пригласить пользователей в это сообщество, введите их имена ниже, чтобы найти и выбрать их.',
    'Updated At' => 'Обновлено в',
    'Updated By' => 'Обновлено',
    'Updated by' => 'Обновлено',
    'User \'{username}\' is already a member of this space!' => 'Пользователь \'{username}\' уже является участником этого сообщества!',
    'User invitations have been added to the queue' => 'Приглашения на вступления для пользователей добавлены',
    'User memberships have been added to the queue' => 'Пользователи приглашены для вступления',
    'User not found!' => 'Пользователь не найден!',
    'Users' => 'Пользователи',
    'Users has been invited.' => 'Пользователи были приглашены.',
    'Visibility' => 'Видимость сообщества',
    'Visible for all (members and guests)' => 'Видимо для всех (для Участников и Гостей)',
    'You are not allowed to join this space!' => 'Вы не можете присоединиться к этому сообществу!',
    'You cannot create private visible spaces!' => 'Вы не можете создавать закрытые сообщества!',
    'You cannot create public visible spaces!' => 'Вы не можете создавать открытые (публичные) сообщества!',
    'You need to login to view contents of this space!' => 'Вы должны войти/зарегистрироваться, чтобы просматривать содержимое этого сообщества!',
    'Your Message' => 'Сообщение',
    'Your request was successfully submitted to the space administrators.' => 'Ваша заявка на вступление была успешно отправлена администратору сообщества.',
    '{count} members' => '{count} участников',
    '{email} is not valid!' => '{email} некорректный!',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Change visibility' => '',
    'Create new link' => '',
    'Find Spaces by their description or by their tags' => '',
    'Guests' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage (Non-members)' => '',
    'I want to become a member because...' => '',
    'Invite by link' => '',
    'Invite link' => '',
    'Join' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Moderator' => '',
    'Name / Sort order' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => '',
    'Send the link via email' => '',
    'Settings could not be saved!' => '',
    'Show as List' => '',
    'Shown on About Page.' => '',
    'Space Visibility' => '',
    'The default homepage for members of this Space' => '',
    'The default homepage for non-members and guests visiting this Space' => '',
    'The secure link has been copied in your clipboard!' => '',
    'Try other keywords or remove filters.' => '',
    'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => '',
];
